#usr/bin/python3.9
import time
import itertools, string
import hashlib
import sys
import signal
import re

class md5_cracker(object):

    def __init__(self):
        print("\nWelcome to md5 hash cracker!")

    def signal_handler(self, signal, frame):
        print('You pressed Ctrl+C!')
        self.done=True
        sys.exit(0)

    def _attack(self, chrs, inputt):
        print ("[+] Started at:", time.strftime('%H:%M:%S'))
        start_time = time.time()
        total_pass_try=0
        for n in range(1, 31+1):
            characterstart_time = time.time()
            print("\n[!] Cracking character number", str(n) +str("..."))
        
            for xs in itertools.product(chrs, repeat=n):
                saved = ''.join(xs)
                stringg = saved
                m = hashlib.md5()
                m.update(saved.encode('utf-8'))
                total_pass_try +=1
                if m.hexdigest() == inputt:
                    time.sleep(10)
                    print('[-] Done.')
                    print("\n[!] Found string:", stringg)
                    print("\n[-] Finished at:", time.strftime('%H:%M:%S'))
                    print("\n[-] Total keywords attempted:", total_pass_try)
                    print("\n---Md5 hash cracked in %s seconds---" % (time.time() - start_time))
                    sys.exit("\nThank You!")
            print('[-] Done.')
        print("\n[!]","Character number", n,"has been cracked in %s seconds!" % (time.time() - characterstart_time))

    def main(self):
        inp_usr = input("\nPaste the md5 hash:\n")
        if re.match(r"([a-fA-F\d]{32})", inp_usr):
            print("\nAlphabet:")
            chrs = string.printable.replace(' \t\n\r\x0b\x0c\n', '')
            print(chrs)
            signal.signal(signal.SIGINT, md5_cracker.signal_handler)
            return md5_cracker._attack(self, chrs, inp_usr);
        else:
            print("Error: Input is not an md5 hash.")
            
if __name__ == "__main__":
    md5 = md5_cracker()
    md5.main()
   
   
   



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['main']
setup_kwargs = {
    'name': 'md5-brute-force',
    'version': '0.3.2',
    'description': 'Python script for brute forcing an md5 hash.',
    'long_description': '# Script to brute force an md5 hash.\n\nThis script is for brute forcing your way through an md5 hash. Clone the repo, install the dependencies, run the script, paste your hash -> done.\n\n# How to use:\nIn order to use this script you must first install `poetry`.\n\nTo install `poetry` on osx or linux use:\n```\ncurl -sSL https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py | python -\n```\nTo install `poetry` on windows powershell use:\n```\n(Invoke-WebRequest -Uri https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py -UseBasicParsing).Content | python -\n```\nClone this Github repository into your current directory before changing into it:\n```\ngit clone https://github.com/vsevolod-mineev/md5-bruteforce\n```\n```\ncd md5-brute-force/\n```\nTo install the defined dependencies for this project use:\n```\npoetry install\n```\nTo execute the command within the virtual environment use:\n```\npoetry run\n```\n\nRun the script using the following format:\n```\npoetry run python3 main.py\n```\n\n# How does it work?\n![md5-brute-force](./images/md5-brute-force-image.png)\n\n',
    'author': 'Vsevolod Mineev',
    'author_email': 'vsevolod.mineev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/vsevolod-mineev/md5-brute-force',
    'py_modules': modules,
    'python_requires': '>=3.9,<3.11',
}


setup(**setup_kwargs)
